os-brick Changelog history
==========================

0.3.0
-----

* Added HGST Solutions connector.
* Added RBD connector.
* Added ScaleIO connector.
* Added Python 3.4 support.

.. _1324670 http://bugs.launchpad.net/cinder/+bug/1324670
.. _1462091 http://bugs.launchpad.net/cinder/+bug/1462091
.. _1382440 http://bugs.launchpad.net/cinder/+bug/1382440
.. _1456480 http://bugs.launchpad.net/cinder/+bug/1456480
.. _1466851 http://bugs.launchpad.net/cinder/+bug/1466851
.. _1469338 http://bugs.launchpad.net/cinder/+bug/1469338

0.2.0
-----
* This release is primarily to resolve some OpenStack global requirements
  conflict issues.

.. _1453992 http://bugs.launchpad.net/cinder/+bug/1453992

0.1.0
-----
* First version of the library
